==> core-react-0.8.0.tgz: package/es/SelectDropdown/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Dropdown, DropdownToggle, DropdownMenu } from '../Dropdown';
import Icon from '../Icon';


var SelectDropdown = /*#__PURE__*/function (_React$Component) {
  _inherits(SelectDropdown, _React$Component);

  function SelectDropdown() {
    _classCallCheck(this, SelectDropdown);

    return _possibleConstructorReturn(this, _getPrototypeOf(SelectDropdown).apply(this, arguments));
  }

  _createClass(SelectDropdown, [{
    key: "close",
    value: function close() {
      this.dropdown.close();
    }
  }, {
    key: "render",
    value: function render() {
      var _this = this;

      var _this$props = this.props,
          className = _this$props.className,
          children = _this$props.children,
          title = _this$props.title,
          url = _this$props.url,
          hasPropValue = _this$props.hasPropValue,
          caret = _this$props.caret,
          onLoad = _this$props.onLoad,
          onToggle = _this$props.onToggle,
          width = _this$props.width,
          disabled = _this$props.disabled,
          other = _objectWithoutProperties(_this$props, ["className", "children", "title", "url", "hasPropValue", "caret", "onLoad", "onToggle", "width", "disabled"]);

      if (width) {
        other.style = Object.assign(other.style || {}, {
          width: width
        });
      }

      return React.createElement(Dropdown, {
        aligned: true,
        onToggle: onToggle,
        disabled: disabled,
        ref: function ref(dropdown) {
          return _this.dropdown = dropdown;
        }
      }, React.createElement(DropdownToggle, _extends({
        className: cx("".concat("waui", "-select-dropdown"), _defineProperty({}, "".concat("waui", "-select-dropdown__dropdown-toggle_caretable"), caret), className)
      }, other), title, caret && React.createElement(Icon, {
        type: "caret-down",
        className: "".concat("waui", "-select-dropdown__caret")
      })), React.createElement(DropdownMenu, {
        className: "".concat("waui", "-select-dropdown__popover")
      }, children));
    }
  }]);

  return SelectDropdown;
}(React.Component);

SelectDropdown.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  title: PropTypes.element.isRequired,
  url: PropTypes.string,
  hasPropValue: PropTypes.bool,
  caret: PropTypes.bool,
  disabled: PropTypes.bool,
  width: PropTypes.number,
  onLoad: PropTypes.func,
  onToggle: PropTypes.func
};
export default SelectDropdown;

==> core-react-0.8.2.tgz: package/es/SelectDropdown/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Dropdown, DropdownToggle, DropdownMenu } from '../Dropdown';
import Icon from '../Icon';


var SelectDropdown = /*#__PURE__*/function (_React$Component) {
  _inherits(SelectDropdown, _React$Component);

  function SelectDropdown() {
    _classCallCheck(this, SelectDropdown);

    return _possibleConstructorReturn(this, _getPrototypeOf(SelectDropdown).apply(this, arguments));
  }

  _createClass(SelectDropdown, [{
    key: "close",
    value: function close() {
      this.dropdown.close();
    }
  }, {
    key: "render",
    value: function render() {
      var _this = this;

      var _this$props = this.props,
          className = _this$props.className,
          children = _this$props.children,
          title = _this$props.title,
          url = _this$props.url,
          hasPropValue = _this$props.hasPropValue,
          caret = _this$props.caret,
          onLoad = _this$props.onLoad,
          onToggle = _this$props.onToggle,
          width = _this$props.width,
          disabled = _this$props.disabled,
          other = _objectWithoutProperties(_this$props, ["className", "children", "title", "url", "hasPropValue", "caret", "onLoad", "onToggle", "width", "disabled"]);

      if (width) {
        other.style = Object.assign(other.style || {}, {
          width: width
        });
      }

      return (/*#__PURE__*/React.createElement(Dropdown, {
          aligned: true,
          onToggle: onToggle,
          disabled: disabled,
          ref: function ref(dropdown) {
            return _this.dropdown = dropdown;
          }
        }, /*#__PURE__*/React.createElement(DropdownToggle, _extends({
          className: cx("".concat("waui", "-select-dropdown"), _defineProperty({}, "".concat("waui", "-select-dropdown__dropdown-toggle_caretable"), caret), className)
        }, other), title, caret && /*#__PURE__*/React.createElement(Icon, {
          type: "caret-down",
          className: "".concat("waui", "-select-dropdown__caret")
        })), /*#__PURE__*/React.createElement(DropdownMenu, {
          className: "".concat("waui", "-select-dropdown__popover")
        }, children))
      );
    }
  }]);

  return SelectDropdown;
}(React.Component);

SelectDropdown.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  title: PropTypes.element.isRequired,
  url: PropTypes.string,
  hasPropValue: PropTypes.bool,
  caret: PropTypes.bool,
  disabled: PropTypes.bool,
  width: PropTypes.number,
  onLoad: PropTypes.func,
  onToggle: PropTypes.func
};
export default SelectDropdown;
